from django import template
from django.conf import settings
from django.templatetags.static import static

from .. settings import *


register = template.Library()

DJANGO_BOOSTRAP_ITALIA_USE_CDN = getattr(settings, 'DJANGO_BOOSTRAP_ITALIA_USE_CDN', DJANGO_BOOSTRAP_ITALIA_USE_CDN)
DJANGO_BOOSTRAP_ITALIA_CDN = getattr(settings, 'DJANGO_BOOSTRAP_ITALIA_CDN', DJANGO_BOOSTRAP_ITALIA_CDN)


@register.simple_tag
def django_bootstrap_italia_static_path(resource):
    if not resource: return ''
    if DJANGO_BOOSTRAP_ITALIA_USE_CDN:
        return f'{DJANGO_BOOSTRAP_ITALIA_CDN}/{resource}'
    return static(resource)



from django.forms.widgets import *
from django.utils.translation import gettext as _


class BootstrapItaliaDateWidget(DateInput):
    template_name = 'widgets/date.html'
    def __init__(self,  *attrs, **kwargs):
        super().__init__(*attrs, **kwargs)
        self.format = '%Y-%m-%d'


class BootstrapItaliaRadioWidget(RadioSelect):
    template_name = 'widgets/radio.html'


class BootstrapItaliaSelectWidget(Select):
    template_name = 'widgets/select.html'

    def __init__(self,  *attrs, **kwargs):
        super().__init__(*attrs, **kwargs)
        self.attrs = {'data-live-search': 'true',
                      'data-live-search-placeholder': _("Cerca...")}


class BootstrapItaliaSelectMultipleWidget(SelectMultiple,
                                          BootstrapItaliaSelectWidget):

    def __init__(self,  *attrs, **kwargs):
        super().__init__(*attrs, **kwargs)
        self.attrs['data-multiple-separator'] = ' - '
